import { __awaiter, __decorate } from "tslib";
import { attr, customElement } from '@genesislcap/web-core';
import { logger } from '../utils';
import { Fdc3SystemChannelListener } from './fdc3-system-channel-listener';
/**
 * fdc3-context-listener
 * Util element to listen to the context on a fdc3 app channel
 * @public
 * @tagname fdc3-context-listener
 * @example
 * ```ts
 * import { customElement, GenesisElement, html } from '@genesislcap/web-core';
 * @customElement({
 *   name: 'example-component',
 *   template: html<ExampleComponent>`
 *    <fdc3-context-listener
 *      @channel-event="${(x, ctx) => x.handleChannelMessage(customEvent(ctx))}"
 *      context-type="fdc3.position"
 *      channel-name="my_custom_channel">
 *    </fdc3-context-listener>
 *   `,
 * })
 * class ExampleComponent extends GenesisElement {
 *   handleChannelMessage(e: CustomEvent) {
 *     const message = e.detail;
 *     if (message?.id?.ticker) {
 *       console.log(message.id.ticker);
 *       // ToDo: handle the message as you like
 *     }
 *   }
 * }
 * ```
 * @param Context - the fdc3 context type
 * @fires channel-event - Dispatched when an event matching the context is dispatched from the system channel
 */
let Fdc3ContextListener = class Fdc3ContextListener extends Fdc3SystemChannelListener {
    addChannelListener() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.contextType) {
                logger.warn('Fdc3SystemChannelListener: no context type provided');
            }
            else if (!this.channelName) {
                logger.warn('Fdc3SystemChannelListener: no channel name provided');
            }
            else {
                const channel = yield this.fdc3.addChannelListener(this.channelName, this.contextType, (context) => {
                    this.$emit('channel-event', context);
                });
                this.fdc3.handleChannelCurrentContext(channel, this.contextType, (context) => {
                    if (context) {
                        this.$emit('channel-event', context);
                    }
                });
            }
        });
    }
};
__decorate([
    attr({ attribute: 'channel-name' })
], Fdc3ContextListener.prototype, "channelName", void 0);
Fdc3ContextListener = __decorate([
    customElement({
        name: 'fdc3-context-listener',
    })
], Fdc3ContextListener);
export { Fdc3ContextListener };
